<?php

/**
 * CelebrioNews Article
 *
 * @copyright  Copyright (c) 2011 Celebrio Software
 * @package    NewsReader
 */

namespace NewsModule;

use \Nette\Object;
use \dibi;

class Article extends Object
{

    private $guid;
    private $title;
    private $publisher;
    private $link;
    private $category;
    private $pub_date;
    private $picture;
    private $content;

    private $rating;
    
    public function __construct($guid, $title, $pub_date, $content, $link = null, $category = null)
    {
	    $this->setGuid($guid);
        $this->setTitle($title);
        $this->setPubDate($pub_date);
        $this->setContent($content);
        $this->setLink($link);
        $this->setCategory($category);
    }

    public static function fromArray(array $article_array)
    {
        $article = new Article($article_array["guid"], $article_array["title"], $article_array["pubdate"], $article_array["content"]);
        if (array_key_exists("link", $article_array)) {
            $article->setLink($article_array["link"]);
        }
        if (array_key_exists("category", $article_array)) {
            $article->setCategory($article_array["category"]);
        }
        if (array_key_exists("rating", $article_array)) {
            $article->setRating($article_array["rating"]);
        }
        if (array_key_exists("picture", $article_array)) {
            $article->setPicture($article_array["picture"]);
        }
        if (array_key_exists("publisher", $article_array)) {
            $article->setPublisher($article_array["publisher"]);
        }
        return $article;
    }

    public function setCategory($category) {
        $this->category = $category;
    }

    public function getCategory() {
        return $this->category;
    }

    public function setContent($content) {
        $this->content = $content;
    }

    public function getContent() {
        return $this->content;
    }

    public function setGuid($guid) {
        $this->guid = $guid;
    }

    public function getGuid() {
        return $this->guid;
    }

    public function setLink($link) {
        $this->link = $link;
    }

    public function getLink() {
        return $this->link;
    }

    public function setPubDate($pub_date) {
        $this->pub_date = $pub_date;
    }

    public function getPubDate() {
        return $this->pub_date;
    }

    public function setTitle($title) {
        $this->title = $title;
    }

    public function getTitle() {
        return $this->title;
    }

    public function setRating($rating) {
        $this->rating = $rating;
    }

    public function getRating() {
        return $this->rating;
    }

    public function setPicture($picture) {
        $this->picture = $picture;
    }

    public function getPicture() {
        return $this->picture;
    }

    public function setPublisher($publisher) {
        $this->publisher = $publisher;
    }

    public function getPublisher() {
        return $this->publisher;
    }

    public function rate($id_language) {
        $result = dibi::select("rating")->from("news")->where(array("guid" => $this->getGuid()))->fetch();
        if ($result) {
        dibi::update("news", array("rating%sql" => "rating+1"))
                ->where(array("guid" => $this->getGuid()))->execute();
        } else {
            $args = $this->to_a(array("rating"));
            $args["id_language"] = $id_language;
            $args["pubdate"] = new \DateTime53($args["pubdate"]);
            dibi::insert("news", $args)->execute();
        }
    }

    private function to_a(array $exclude = array()) {
        $article = array(
            "guid" => $this->getGuid(),
            "title" => $this->getTitle(),
            "publisher" => $this->getPublisher(),
            "link" => $this->getLink(),
            "category" => $this->getCategory(),
            "pubdate" => $this->getPubDate(),
            "picture" => $this->getPicture(),
            "content" => $this->getContent(),
            "rating" => $this->getRating(),
        );
        foreach ($exclude as $ex) {
            unset($article[$ex]);
        }
        return $article;
    }
}