<?php
namespace NewsModule;

use Nette\Object;

class NewsManagement extends Object {

    public static function allCategories() {
        $categories = array();

        $categories["czech"] = array(
            "title" => "Domácí",
            "icon" => "main_news.png",
        );
        $categories['world'] = array(
            "title" => "Ze světa",
            "icon" => "world.png",
        );
        $categories['entertainment'] = array(
            "title" => "Kultura",
            "icon" => "theater_masks.png",
        );
        $categories['history'] = array(
            "title" => "Historie",
            "icon" => "history.png",
        );
        $categories['causes'] = array(
            "title" => "Kauzy",
            "icon" => "causes.png",
        );
        $categories['economy'] = array(
            "title" => "Ekonomika",
            "icon" => "economy.png",
        );
        $categories['technology'] = array(
            "title" => "Technologie",
            "icon" => "technology.png",
        );

        $categories['sports'] = array(
            "title" => "Sport",
            "icon" => "soccer_ball.png",
        );

        return $categories;
    }

    public function getCategories() {
        $categories = array();
        $categoriesToReturn = array();
        $allCategories = static::allCategories();
        foreach ($this->getSelectedReaders() as $reader) {
            $categories = array_merge($categories, $reader->getCategories());
        }

        foreach ($categories as $key => $value) {
            $categoriesToReturn[$key] = $allCategories[$key];
        }


        return $categoriesToReturn;
    }

    public function getCategoryTitle($idCategory) {

    }

    public function getList($idCategory) {
        $newsItems = array();
        foreach ($this->getSelectedReaders() as $reader) {
            $news = $reader->fetchNews($idCategory);
            if(!empty($news)) {
                $newsItems = array_merge($newsItems, array_slice($news['items'], 0, 10));
            }
        }

        //usort($newsItems, array($this, "sortItems"));
        return $newsItems;
    }

    public function getStory($id, $category, $reader) {
        $selectedReaders = $this->getSelectedReaders();
        if(array_key_exists($reader, $selectedReaders)) {
            return $selectedReaders[$reader]->getStory($id, $category);
        }
        return null;
    }

    public function getAllReaders() {
        $readers = array();
        $readers["ct"] = new CtNewsReader();
        $readers["ct4"] = new CtSportNewsReader();
        $readers["idnes"] = new IdnesNewsReader();

        return array_filter($readers, array($this, "feedLanguage"));
    }

    public function getReaderList() {
        $readerList = array();
        foreach ($this->getAllReaders() as $reader) {
            $readerList[$reader->getKey()] = $reader->getLogo();
        }

        return $readerList;
    }

    public function getSelectedReaders() {
        return $this->getAllReaders();;
    }

    private function sortItems($first, $second) {
        $date1 = $first["pubtimestamp"];
        $date2 = $second["pubtimestamp"];
        if ($date1 == $date2) {
            return 0;
        } else {
            return $date1 < $date2 ? 1 : -1;
        }
    }

    private function feedLanguage($value) {
        return "cs";
    }
}
