<?php

/**
 * CelebrioNews default
 *
 * @copyright  Copyright (c) 2011 Celebrio Software
 * @package    CelebrioNews
 */

namespace NewsModule;

use Application\BasePresenter;
use Celebrio\Menu;

/**
 * @author Petr
 */
class DefaultPresenter extends BasePresenter {

    private $newsManager = null;

    public function beforeRender() {
        parent::beforeRender();
        $this->getTemplate()->desktop = true;
        $this->getTemplate()->app_name = "Zprávy";
    }

    /**
     * Renders the main news menu, containing the news categories
     * 
     * @return void
     */
    public function renderDefault() {
        $this->getTemplate()->manifest = "apps/news/news.appcache";
        $this->getTemplate()->categories = $this->getNewsManager()->getCategories();
        $this->getTemplate()->menuWidth = Menu::widthCount(count($this->getTemplate()->categories)+1);
        $this->getTemplate()->title = "Zprávy";
    }

    /**
     * Renders the list of the news in the given category (with their previews).
     * 
     * @param string $id
     * @return void
     */
    public function renderList($id) {
        $newsManager = $this->getNewsManager();
        $news = $newsManager->getList($id);

        $this->getTemplate()->category_id = $id;
        $this->getTemplate()->news = $news;
        $this->getTemplate()->menuWidth = Menu::width($news, 270);
        $categories = NewsManagement::allCategories();
        $this->getTemplate()->title = $categories[$id]["title"];
        $this->getTemplate()->back = $this->link("default");
    }

    public function renderDetail($id, $category, $reader, $offline = false) {
        // render all the text of the news entry which id we've got
        //$story = $this->newsReader->getStory($id, $category);
        $story = $this->getNewsManager()->getStory($id, $category, $reader);

        $this->getTemplate()->vertical = true;
        $this->getTemplate()->top = true;
        $this->getTemplate()->article = $story;
        $this->getTemplate()->article_json = json_encode($story);
        $categories = NewsManagement::allCategories();
        if ($offline) {
            $this->getTemplate()->manifest = "apps/news/news.appcache";
        }
        $this->getTemplate()->back = $this->link("list", $category);
        $this->getTemplate()->title = $categories[$category]["title"];
    }
    
    public function renderOffline () {
        $this->getTemplate()->manifest = "apps/news/news.appcache";
        $this->getTemplate()->title = "Uložené";
        $this->getTemplate()->back = $this->link("default");
    }

    private function getNewsManager() {
        if ($this->newsManager == null) {
            $this->newsManager = new NewsManagement();
        }
        return $this->newsManager;
    }

}